import os


def get_include():
    """Retrieve the path to compiled C extensions' source files to make linking simple.

    This module contains two variants of the algorithm reimplimented using C and the Python-C API.
    """
    return os.path.dirname(__file__)



#   Copyright 2016 Joshua Klein, Lev Levitsky
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.



cpdef list parse(str sequence, bint show_unmodified_termini=*, bint split=*,
                 bint allow_unknown_modifications=*, object  labels=*)

cpdef dict amino_acid_composition(object sequence, bint show_unmodified_termini=*, bint term_aa=*,
                                  bint allow_unknown_modifications=*, object labels=*)

cpdef tuple _split_label(str label)

cpdef str tostring(object parsed_sequence, bint show_unmodified_termini=*)



#!/usr/bin/env python
from setuptools import setup, Extension, find_namespace_packages

try:
    from Cython.Build import cythonize
    extensions = cythonize(
        [
            Extension(name="pyteomics.cparser", sources=["pyteomics/cparser.pyx"]),
            Extension(name="pyteomics.cmass", sources=["pyteomics/cmass.pyx"]),
        ]
    )
except ImportError:
    extensions = [
        Extension(name="pyteomics.cparser", sources=["pyteomics/cparser.c"]),
        Extension(name="pyteomics.cmass", sources=["pyteomics/cmass.c"]),
    ]


setup(
    name="pyteomics.cythonize",
    description="An Cython-accelerated version of common pyteomics functions",
    long_description=open("README.rst").read(),
    version="0.2.9",
    packages=find_namespace_packages(include=["pyteomics*"]),
    zip_safe=False,
    install_requires=["pyteomics"],
    include_package_data=True,
    ext_modules=extensions,
    maintainer="Joshua Klein",
    maintainer_email="jaklein@bu.edu",
    classifiers=[
        "Intended Audience :: Science/Research",
        "Programming Language :: Python :: 3",
        "Topic :: Education",
        "Topic :: Scientific/Engineering :: Bio-Informatics",
        "Topic :: Scientific/Engineering :: Chemistry",
        "Topic :: Software Development :: Libraries",
    ],
    license="License :: OSI Approved :: Apache Software License",
    url="https://github.com/mobiusklein/pyteomics.cythonize",
)
